@@ -13,6 +13,7 @@
 #include <openvdb/util/logging.h>
 #include <openvdb/openvdb.h>
 
+#ifdef OPENVDB_USE_DELAYED_LOADING
 // Boost.Interprocess uses a header-only portion of Boost.DateTime
 #ifdef __clang__
 #pragma clang diagnostic push
@@ -26,10 +27,6 @@
 #include <boost/interprocess/mapped_region.hpp>
 #include <boost/iostreams/device/array.hpp>
 #include <boost/iostreams/stream.hpp>
-#include <boost/uuid/uuid_generators.hpp>
-#include <boost/uuid/uuid_io.hpp>
-
-#include <atomic>
 
 #ifdef _WIN32
 #include <boost/interprocess/detail/os_file_functions.hpp> // open_existing_file(), close_file()
@@ -43,6 +40,10 @@ namespace boost { namespace interprocess { namespace detail {} namespace ipcdeta
 #include <sys/stat.h> // for stat()
 #include <unistd.h> // for unlink()
 #endif
+#endif // OPENVDB_USE_DELAYED_LOADING
+
+#include <atomic>
+
 #include <algorithm> // for std::find_if()
 #include <cerrno> // for errno
 #include <cstdlib> // for getenv()
@@ -98,8 +99,13 @@ struct StreamState
     int halfFloat;
     int mappedFile;
     int metadata;
+};
+
+inline StreamState& GetSteamState()
+{
+    static StreamState sStreamState;
+    return sStreamState;
 }
-sStreamState;
 
 const long StreamState::MAGIC_NUMBER =
     long((uint64_t(OPENVDB_MAGIC) << 32) | (uint64_t(OPENVDB_MAGIC)));
@@ -324,10 +330,10 @@ namespace {
 
 template<typename T>
 inline bool
-writeAsType(std::ostream& os, const boost::any& val)
+writeAsType(std::ostream& os, const std::any& val)
 {
     if (val.type() == typeid(T)) {
-        os << boost::any_cast<T>(val);
+        os << std::any_cast<T>(val);
         return true;
     }
     return false;
@@ -409,8 +415,8 @@ operator<<(std::ostream& os, const StreamMetadata::AuxDataMap& auxData)
         it != end; ++it)
     {
         os << it->first << ": ";
-        // Note: boost::any doesn't support serialization.
-        const boost::any& val = it->second;
+        // Note: std::any doesn't support serialization.
+        const std::any& val = it->second;
         if (!writeAsType<int32_t>(os, val)
             && !writeAsType<int64_t>(os, val)
             && !writeAsType<int16_t>(os, val)
@@ -437,6 +443,9 @@ operator<<(std::ostream& os, const StreamMetadata::AuxDataMap& auxData)
 ////////////////////////////////////////
 
 
+#ifdef OPENVDB_USE_DELAYED_LOADING
+
+
 // Memory-mapping a VDB file permits threaded input (and output, potentially,
 // though that might not be practical for compressed files or files containing
 // multiple grids).  In particular, a memory-mapped file can be loaded lazily,
@@ -575,6 +584,9 @@ MappedFile::clearNotifier()
 }
 
 
+#endif // OPENVDB_USE_DELAYED_LOADING
+
+
 ////////////////////////////////////////
 
 
@@ -598,7 +610,7 @@ getErrorString()
 Archive::Archive()
     : mFileVersion(OPENVDB_FILE_VERSION)
     , mLibraryVersion(OPENVDB_LIBRARY_MAJOR_VERSION, OPENVDB_LIBRARY_MINOR_VERSION)
-    , mUuid(boost::uuids::nil_uuid())
+    , mUuid()
     , mInputHasGridOffsets(false)
     , mEnableInstancing(true)
     , mCompression(DEFAULT_COMPRESSION_FLAGS)
@@ -625,13 +637,17 @@ Archive::copy() const
 std::string
 Archive::getUniqueTag() const
 {
-    return boost::uuids::to_string(mUuid);
+    return mUuid;
 }
 
 
 bool
 Archive::isIdentical(const std::string& uuidStr) const
 {
+    // If either uuids are blank, they will always fail to match
+    // as something went wrong generating them.
+    if (uuidStr.empty()) return false;
+    if (getUniqueTag().empty()) return false;
     return uuidStr == getUniqueTag();
 }
 
@@ -643,14 +659,14 @@ uint32_t
 getFormatVersion(std::ios_base& is)
 {
     /// @todo get from StreamMetadata
-    return static_cast<uint32_t>(is.iword(sStreamState.fileVersion));
+    return static_cast<uint32_t>(is.iword(GetSteamState().fileVersion));
 }
 
 
 void
 Archive::setFormatVersion(std::istream& is)
 {
-    is.iword(sStreamState.fileVersion) = mFileVersion; ///< @todo remove
+    is.iword(GetSteamState().fileVersion) = mFileVersion; ///< @todo remove
     if (StreamMetadata::Ptr meta = getStreamMetadataPtr(is)) {
         meta->setFileVersion(mFileVersion);
     }
@@ -662,8 +678,8 @@ getLibraryVersion(std::ios_base& is)
 {
     /// @todo get from StreamMetadata
     VersionId version;
-    version.first = static_cast<uint32_t>(is.iword(sStreamState.libraryMajorVersion));
-    version.second = static_cast<uint32_t>(is.iword(sStreamState.libraryMinorVersion));
+    version.first = static_cast<uint32_t>(is.iword(GetSteamState().libraryMajorVersion));
+    version.second = static_cast<uint32_t>(is.iword(GetSteamState().libraryMinorVersion));
     return version;
 }
 
@@ -671,8 +687,8 @@ getLibraryVersion(std::ios_base& is)
 void
 Archive::setLibraryVersion(std::istream& is)
 {
-    is.iword(sStreamState.libraryMajorVersion) = mLibraryVersion.first; ///< @todo remove
-    is.iword(sStreamState.libraryMinorVersion) = mLibraryVersion.second; ///< @todo remove
+    is.iword(GetSteamState().libraryMajorVersion) = mLibraryVersion.first; ///< @todo remove
+    is.iword(GetSteamState().libraryMinorVersion) = mLibraryVersion.second; ///< @todo remove
     if (StreamMetadata::Ptr meta = getStreamMetadataPtr(is)) {
         meta->setLibraryVersion(mLibraryVersion);
     }
@@ -692,9 +708,9 @@ getVersion(std::ios_base& is)
 void
 setCurrentVersion(std::istream& is)
 {
-    is.iword(sStreamState.fileVersion) = OPENVDB_FILE_VERSION; ///< @todo remove
-    is.iword(sStreamState.libraryMajorVersion) = OPENVDB_LIBRARY_MAJOR_VERSION; ///< @todo remove
-    is.iword(sStreamState.libraryMinorVersion) = OPENVDB_LIBRARY_MINOR_VERSION; ///< @todo remove
+    is.iword(GetSteamState().fileVersion) = OPENVDB_FILE_VERSION; ///< @todo remove
+    is.iword(GetSteamState().libraryMajorVersion) = OPENVDB_LIBRARY_MAJOR_VERSION; ///< @todo remove
+    is.iword(GetSteamState().libraryMinorVersion) = OPENVDB_LIBRARY_MINOR_VERSION; ///< @todo remove
     if (StreamMetadata::Ptr meta = getStreamMetadataPtr(is)) {
         meta->setFileVersion(OPENVDB_FILE_VERSION);
         meta->setLibraryVersion(VersionId(
@@ -706,9 +722,9 @@ setCurrentVersion(std::istream& is)
 void
 setVersion(std::ios_base& strm, const VersionId& libraryVersion, uint32_t fileVersion)
 {
-    strm.iword(sStreamState.fileVersion) = fileVersion; ///< @todo remove
-    strm.iword(sStreamState.libraryMajorVersion) = libraryVersion.first; ///< @todo remove
-    strm.iword(sStreamState.libraryMinorVersion) = libraryVersion.second; ///< @todo remove
+    strm.iword(GetSteamState().fileVersion) = fileVersion; ///< @todo remove
+    strm.iword(GetSteamState().libraryMajorVersion) = libraryVersion.first; ///< @todo remove
+    strm.iword(GetSteamState().libraryMinorVersion) = libraryVersion.second; ///< @todo remove
     if (StreamMetadata::Ptr meta = getStreamMetadataPtr(strm)) {
         meta->setFileVersion(fileVersion);
         meta->setLibraryVersion(libraryVersion);
@@ -732,14 +748,14 @@ uint32_t
 getDataCompression(std::ios_base& strm)
 {
     /// @todo get from StreamMetadata
-    return uint32_t(strm.iword(sStreamState.dataCompression));
+    return uint32_t(strm.iword(GetSteamState().dataCompression));
 }
 
 
 void
 setDataCompression(std::ios_base& strm, uint32_t c)
 {
-    strm.iword(sStreamState.dataCompression) = c; ///< @todo remove
+    strm.iword(GetSteamState().dataCompression) = c; ///< @todo remove
     if (StreamMetadata::Ptr meta = getStreamMetadataPtr(strm)) {
         meta->setCompression(c);
     }
@@ -821,14 +837,14 @@ bool
 getWriteGridStatsMetadata(std::ios_base& strm)
 {
     /// @todo get from StreamMetadata
-    return strm.iword(sStreamState.writeGridStatsMetadata) != 0;
+    return strm.iword(GetSteamState().writeGridStatsMetadata) != 0;
 }
 
 
 void
 setWriteGridStatsMetadata(std::ios_base& strm, bool writeGridStats)
 {
-    strm.iword(sStreamState.writeGridStatsMetadata) = writeGridStats; ///< @todo remove
+    strm.iword(GetSteamState().writeGridStatsMetadata) = writeGridStats; ///< @todo remove
     if (StreamMetadata::Ptr meta = getStreamMetadataPtr(strm)) {
         meta->setWriteGridStats(writeGridStats);
     }
@@ -842,7 +858,7 @@ uint32_t
 getGridClass(std::ios_base& strm)
 {
     /// @todo get from StreamMetadata
-    const uint32_t val = static_cast<uint32_t>(strm.iword(sStreamState.gridClass));
+    const uint32_t val = static_cast<uint32_t>(strm.iword(GetSteamState().gridClass));
     if (val >= NUM_GRID_CLASSES) return GRID_UNKNOWN;
     return val;
 }
@@ -851,7 +867,7 @@ getGridClass(std::ios_base& strm)
 void
 setGridClass(std::ios_base& strm, uint32_t cls)
 {
-    strm.iword(sStreamState.gridClass) = long(cls); ///< @todo remove
+    strm.iword(GetSteamState().gridClass) = long(cls); ///< @todo remove
     if (StreamMetadata::Ptr meta = getStreamMetadataPtr(strm)) {
         meta->setGridClass(cls);
     }
@@ -862,14 +878,14 @@ bool
 getHalfFloat(std::ios_base& strm)
 {
     /// @todo get from StreamMetadata
-    return strm.iword(sStreamState.halfFloat) != 0;
+    return strm.iword(GetSteamState().halfFloat) != 0;
 }
 
 
 void
 setHalfFloat(std::ios_base& strm, bool halfFloat)
 {
-    strm.iword(sStreamState.halfFloat) = halfFloat; ///< @todo remove
+    strm.iword(GetSteamState().halfFloat) = halfFloat; ///< @todo remove
     if (StreamMetadata::Ptr meta = getStreamMetadataPtr(strm)) {
         meta->setHalfFloat(halfFloat);
     }
@@ -880,24 +896,25 @@ const void*
 getGridBackgroundValuePtr(std::ios_base& strm)
 {
     /// @todo get from StreamMetadata
-    return strm.pword(sStreamState.gridBackground);
+    return strm.pword(GetSteamState().gridBackground);
 }
 
 
 void
 setGridBackgroundValuePtr(std::ios_base& strm, const void* background)
 {
-    strm.pword(sStreamState.gridBackground) = const_cast<void*>(background); ///< @todo remove
+    strm.pword(GetSteamState().gridBackground) = const_cast<void*>(background); ///< @todo remove
     if (StreamMetadata::Ptr meta = getStreamMetadataPtr(strm)) {
         meta->setBackgroundPtr(background);
     }
 }
 
 
+#ifdef OPENVDB_USE_DELAYED_LOADING
 MappedFile::Ptr
 getMappedFilePtr(std::ios_base& strm)
 {
-    if (const void* ptr = strm.pword(sStreamState.mappedFile)) {
+    if (const void* ptr = strm.pword(GetSteamState().mappedFile)) {
         return *static_cast<const MappedFile::Ptr*>(ptr);
     }
     return MappedFile::Ptr();
@@ -907,14 +924,15 @@ getMappedFilePtr(std::ios_base& strm)
 void
 setMappedFilePtr(std::ios_base& strm, io::MappedFile::Ptr& mappedFile)
 {
-    strm.pword(sStreamState.mappedFile) = &mappedFile;
+    strm.pword(GetSteamState().mappedFile) = &mappedFile;
 }
+#endif // OPENVDB_USE_DELAYED_LOADING
 
 
 StreamMetadata::Ptr
 getStreamMetadataPtr(std::ios_base& strm)
 {
-    if (const void* ptr = strm.pword(sStreamState.metadata)) {
+    if (const void* ptr = strm.pword(GetSteamState().metadata)) {
         return *static_cast<const StreamMetadata::Ptr*>(ptr);
     }
     return StreamMetadata::Ptr();
@@ -924,7 +942,7 @@ getStreamMetadataPtr(std::ios_base& strm)
 void
 setStreamMetadataPtr(std::ios_base& strm, StreamMetadata::Ptr& meta, bool transfer)
 {
-    strm.pword(sStreamState.metadata) = &meta;
+    strm.pword(GetSteamState().metadata) = &meta;
     if (transfer && meta) meta->transferTo(strm);
 }
 
@@ -933,7 +951,7 @@ StreamMetadata::Ptr
 clearStreamMetadataPtr(std::ios_base& strm)
 {
     StreamMetadata::Ptr result = getStreamMetadataPtr(strm);
-    strm.pword(sStreamState.metadata) = nullptr;
+    strm.pword(GetSteamState().metadata) = nullptr;
     return result;
 }
 
@@ -1001,16 +1019,37 @@ Archive::readHeader(std::istream& is)
     }
 
     // 6) Read the 16-byte (128-bit) uuid.
-    boost::uuids::uuid oldUuid = mUuid;
+    std::string oldUuid = mUuid;
     if (mFileVersion >= OPENVDB_FILE_VERSION_BOOST_UUID) {
-        // UUID is stored as an ASCII string.
-        is >> mUuid;
+        // UUID is stored as fixed-length ASCII string
+        // The extra 4 bytes are for the hyphens.
+        char uuidValues[16*2+4+1];
+        is.read(uuidValues, 16*2+4);
+        uuidValues[16*2+4] = 0;
+        mUuid = uuidValues;
     } else {
         // Older versions stored the UUID as a byte string.
         char uuidBytes[16];
         is.read(uuidBytes, 16);
-        std::memcpy(&mUuid.data[0], uuidBytes, std::min<size_t>(16, mUuid.size()));
+        char uuidStr[33];
+        auto to_hex = [](unsigned int c) -> char
+        {
+            c &= 0xf;
+            if (c < 10) return (char)('0' + c);
+            return (char)(c - 10 + 'A');
+        };
+        for (int i = 0; i < 16; i++)
+        {
+            uuidStr[i*2] = to_hex(uuidBytes[i] >> 4);
+            uuidStr[i*2+1] = to_hex(uuidBytes[i]);
+        }
+        uuidStr[32] = 0;
+        mUuid = uuidStr;
     }
+
+    // CHeck if new and old uuid differ.  If either are blank, they
+    // differ because an error occurred.
+    if (oldUuid.empty() || mUuid.empty()) return true;
     return oldUuid != mUuid; // true if UUID in input stream differs from old UUID
 }
 
@@ -1039,12 +1078,53 @@ Archive::writeHeader(std::ostream& os, bool seekable) const
     // 5) Write a flag indicating that this stream contains compressed leaf data.
     //    (Omitted as of version 222)
 
-    // 6) Generate a new random 16-byte (128-bit) uuid and write it to the stream.
-    std::mt19937 ran;
-    ran.seed(std::mt19937::result_type(std::random_device()() + std::time(nullptr)));
-    boost::uuids::basic_random_generator<std::mt19937> gen(&ran);
-    mUuid = gen(); // mUuid is mutable
-    os << mUuid;
+    // 6) Generate a new random 16-byte (128-bit) sequence and write it to the stream.
+
+    char uuidStr[16*2+4+1];
+    auto to_hex = [](unsigned int c) -> char
+    {
+        c &= 0xf;
+        if (c < 10) return (char)('0' + c);
+        return (char)(c - 10 + 'A');
+    };
+
+    try
+    {
+        std::random_device  seed;
+        for (int i = 0; i < 4; i++)
+        {
+            unsigned int v = seed();
+            // This writes out in reverse direction of bit order, but
+            // as source is random we don't mind.
+            for (int j = 0; j < 8; j++)
+            {
+                uuidStr[i*8+j] = to_hex(v);
+                v >>= 4;
+            }
+        }
+    }
+    catch (std::exception&)
+    {
+        // We could have failed due to running out of entropy, but hopefully
+        // most platforms use /dev/urandom equivalent...
+        // Create a blank UUID that means it should always fail comparisons.
+        uuidStr[0] = 0;
+    }
+    // Insert our hyphens.
+    for (int i = 0; i < 4; i++)
+        uuidStr[16*2+i] = '-';
+    std::swap(uuidStr[16*2+0], uuidStr[8+0]);
+    std::swap(uuidStr[16*2+1], uuidStr[12+1]);
+    std::swap(uuidStr[16*2+2], uuidStr[16+2]);
+    std::swap(uuidStr[16*2+3], uuidStr[20+3]);
+    uuidStr[16*2+4] = 0;
+    mUuid = uuidStr; // mUuid is mutable
+    // We don't write a string; but instead a fixed length buffer.
+    // To match the old UUID, we need an extra 4 bytes for hyphens.
+    for (int i = 0; i < 16*2+4; i++)
+    {
+        os << uuidStr[i];
+    }
 }
 
 
@@ -1098,7 +1178,11 @@ Archive::connectInstance(const GridDescriptor& gd, const NamedGridMap& grids) co
 bool
 Archive::isDelayedLoadingEnabled()
 {
+#ifdef OPENVDB_USE_DELAYED_LOADING
     return (nullptr == std::getenv("OPENVDB_DISABLE_DELAYED_LOAD"));
+#else
+    return false;
+#endif
 }
 
 
@@ -1122,8 +1206,8 @@ doReadGrid(GridBase::Ptr grid, const GridDescriptor& gd, std::istream& is, const
 
     // Restore the file-level stream metadata on exit.
     struct OnExit {
-        OnExit(std::ios_base& strm_): strm(&strm_), ptr(strm_.pword(sStreamState.metadata)) {}
-        ~OnExit() { strm->pword(sStreamState.metadata) = ptr; }
+        OnExit(std::ios_base& strm_): strm(&strm_), ptr(strm_.pword(GetSteamState().metadata)) {}
+        ~OnExit() { strm->pword(GetSteamState().metadata) = ptr; }
         std::ios_base* strm;
         void* ptr;
     };
@@ -1347,8 +1431,8 @@ Archive::writeGrid(GridDescriptor& gd, GridBase::ConstPtr grid,
 {
     // Restore file-level stream metadata on exit.
     struct OnExit {
-        OnExit(std::ios_base& strm_): strm(&strm_), ptr(strm_.pword(sStreamState.metadata)) {}
-        ~OnExit() { strm->pword(sStreamState.metadata) = ptr; }
+        OnExit(std::ios_base& strm_): strm(&strm_), ptr(strm_.pword(GetSteamState().metadata)) {}
+        ~OnExit() { strm->pword(GetSteamState().metadata) = ptr; }
         std::ios_base* strm;
         void* ptr;
     };
