@@ -12,6 +12,17 @@ C++-to-Python bindings, not the OpenVDB library itself.
 import os, os.path
 import sys
 import unittest
+import inspect
+
+# If on Windows, add required dll directories from our binary build tree
+if 'add_dll_directory' in dir(os):
+    # Should be something like Release, Debug, etc
+    config = os.path.basename(os.getcwd())
+    os.add_dll_directory(os.getcwd() + '\\..\\..\\' + config)
+    if os.getenv('OPENVDB_TEST_PYTHON_AX'):
+        os.add_dll_directory(os.getcwd() +
+            '\\..\\..\\..\\..\\openvdb_ax\\openvdb_ax\\' + config)
+
 import pyopenvdb as openvdb
 
 
@@ -33,6 +44,19 @@ def valueFactory(zeroValue, elemValue):
     return val
 
 
+def ax_is_enabled():
+    '''
+    Return true if we should be testing pyopenvdb.ax(). This environment
+    variable is set by the CMake test command if we expect AX to be tested.
+    '''
+    ax_hook_exists = 'ax' in dir(openvdb) and inspect.isbuiltin(openvdb.ax)
+    ax_is_enabled = os.getenv('OPENVDB_TEST_PYTHON_AX')
+    if ax_is_enabled and not ax_hook_exists:
+        raise RuntimeError('Expected to test the AX python hooks but '
+            'pyopenvdb.ax() has not been located.')
+    return ax_is_enabled
+
+
 class TestOpenVDB(unittest.TestCase):
 
     def run(self, result=None, *args, **kwargs):
@@ -60,6 +84,47 @@ class TestOpenVDB(unittest.TestCase):
             self.assertEqual(grid.activeVoxelCount(), 1)
 
 
+    def testAX(self):
+        if not ax_is_enabled():
+            return
+
+        float_grid = openvdb.FloatGrid()
+        float_grid.name = 'float_grid'
+        ijk = (1, 1, 1)
+
+        acc = float_grid.getAccessor()
+        acc.setValueOn((ijk))
+        self.assertEqual(acc.getValue(ijk), 0)
+
+        openvdb.ax('@float_grid = 2;', float_grid)
+        self.assertEqual(acc.getValue(ijk), 2)
+        acc.setValueOn((ijk))
+
+        float_grid.fill((0, 0, 0), (7, 7, 7), -1, active=True)
+        openvdb.ax('@float_grid = lengthsq(getcoord());', float_grid)
+
+        for i in range(0, 8):
+            for j in range(0, 8):
+                for k in range(0, 8):
+                    ijk = (i, j, k)
+                    lsq = (i*i)+(j*j)+(k*k)
+                    self.assertEqual(acc.getValue(ijk), lsq)
+
+        vec3_grid = openvdb.Vec3SGrid()
+        vec3_grid.name = 'vec_grid'
+
+        vec3_grid.fill((0, 0, 0), (7, 7, 7), (-1,-1,-1), active=True)
+        openvdb.ax('v@vec_grid = @float_grid;', [vec3_grid, float_grid])
+        acc = vec3_grid.getAccessor()
+
+        for i in range(0, 8):
+            for j in range(0, 8):
+                for k in range(0, 8):
+                    ijk = (i, j, k)
+                    lsq = (i*i)+(j*j)+(k*k)
+                    self.assertEqual(acc.getValue(ijk), (lsq,lsq,lsq))
+
+
     def testTransform(self):
         xform1 = openvdb.createLinearTransform(
             [[.5,  0,  0,  0],
@@ -512,7 +577,7 @@ class TestOpenVDB(unittest.TestCase):
                 (ARRAY_DIM, ARRAY_DIM, ARRAY_DIM),      # scalar array
                 (ARRAY_DIM, ARRAY_DIM, ARRAY_DIM, 3)    # vec3 array
             ):
-                for dtype in (np.float32, np.int32, np.float64, np.int64, np.uint32, np.bool):
+                for dtype in (np.float32, np.int32, np.float64, np.int64, np.uint32, bool):
                     # Create a NumPy array, fill it with the background value,
                     # then set some elements to the foreground value.
                     arr = np.ndarray(shape, dtype)
@@ -611,7 +676,7 @@ class TestOpenVDB(unittest.TestCase):
                 (ARRAY_DIM, ARRAY_DIM, ARRAY_DIM),      # scalar array
                 (ARRAY_DIM, ARRAY_DIM, ARRAY_DIM, 3)    # vec3 array
             ):
-                for dtype in (np.float32, np.int32, np.float64, np.int64, np.uint32, np.bool):
+                for dtype in (np.float32, np.int32, np.float64, np.int64, np.uint32, bool):
                     # Return a new NumPy array.
                     arr = np.ndarray(shape, dtype)
                     arr.fill(-100)
@@ -722,15 +787,12 @@ class TestOpenVDB(unittest.TestCase):
         # Vector-valued grids can't be used to store level sets.
         self.assertRaises(TypeError, lambda: openvdb.Vec3SGrid.createLevelSetFromPolygons(
             cubePoints, quads=cubeQuads, transform=xform, halfWidth=halfWidth))
-        # The "points" argument to createLevelSetFromPolygons() must be a NumPy array.
-        self.assertRaises(TypeError, lambda: openvdb.FloatGrid.createLevelSetFromPolygons(
-            cubeVertices, quads=cubeQuads, transform=xform, halfWidth=halfWidth))
-        # The "points" argument to createLevelSetFromPolygons() must be a NumPy float or int array.
-        self.assertRaises(TypeError, lambda: openvdb.FloatGrid.createLevelSetFromPolygons(
-            np.array(cubeVertices, bool), quads=cubeQuads, transform=xform, halfWidth=halfWidth))
+        # The "points" argument to createLevelSetFromPolygons() can be a regular array.
+        openvdb.FloatGrid.createLevelSetFromPolygons(cubeVertices, quads=cubeQuads, transform=xform, halfWidth=halfWidth)
+        # The "points" argument to createLevelSetFromPolygons() can be an array that's implicitly convertible to float
+        openvdb.FloatGrid.createLevelSetFromPolygons(np.array(cubeVertices, bool), quads=cubeQuads, transform=xform, halfWidth=halfWidth)
         # The "triangles" argument to createLevelSetFromPolygons() must be an N x 3 NumPy array.
-        self.assertRaises(TypeError, lambda: openvdb.FloatGrid.createLevelSetFromPolygons(
-            cubePoints, triangles=cubeQuads, transform=xform, halfWidth=halfWidth))
+        self.assertRaises(TypeError, lambda: openvdb.FloatGrid.createLevelSetFromPolygons(cubePoints, triangles=cubeQuads, transform=xform, halfWidth=halfWidth))
 
         # Test volume to mesh conversion.
 
