@@ -9,6 +9,7 @@
 #include "openvdb_ax/codegen/FunctionTypes.h"
 #include "openvdb_ax/codegen/Types.h"
 #include "openvdb_ax/codegen/Utils.h"
+#include "openvdb_ax/util/x86.h"
 
 namespace openvdb {
 OPENVDB_USE_VERSION_NAMESPACE
@@ -39,7 +40,7 @@ inline FunctionGroup::UniquePtr axtrncdecode()
 
         if (type->isIntegerTy() || type->isFloatingPointTy())
         {
-            in = B.CreateLoad(in);
+            in = ir_load(B, in);
             const bool intconversion = type->isIntegerTy();
             assert(intconversion || type->isHalfTy());
             llvm::Value* result = intconversion ?
@@ -91,7 +92,7 @@ inline FunctionGroup::UniquePtr axtrncencode()
 
         if (type->isIntegerTy() || type->isFloatingPointTy())
         {
-            in = B.CreateLoad(in);
+            in = ir_load(B, in);
             const bool intconversion = in->getType()->isIntegerTy();
             assert(intconversion || in->getType()->isFloatTy());
             llvm::Value* result = intconversion ?
@@ -145,7 +146,7 @@ inline FunctionGroup::UniquePtr axfxptdecode(const bool OneByte, const bool IsPo
 
         if (type->isIntegerTy())
         {
-            in = B.CreateLoad(in);
+            in = ir_load(B, in);
             assert(type->isIntegerTy(8) || type->isIntegerTy(16));
             llvm::Value* s = B.CreateUIToFP(in, B.getFloatTy());
             llvm::Value* d = type->isIntegerTy(8) ?
@@ -202,7 +203,7 @@ inline FunctionGroup::UniquePtr axfxptencode(const bool OneByte, const bool IsPo
         llvm::Function* base = B.GetInsertBlock()->getParent();
         llvm::Value* u = args[0]; // out
         llvm::Value* s = args[1]; // in
-        s = B.CreateLoad(s);
+        s = ir_load(B, s);
 
         llvm::Value* offset = LLVMType<float>::get(B.getContext(), 0.5f);
         if (IsPositionRange) s = B.CreateFAdd(s, offset);
@@ -324,24 +325,55 @@ const CodecTypeMap& getCodecTypeMap()
         std::make_unique<Codec>(axprfxpt16encode(), axprfxpt16decode(), 1<<4),
     };
 
-    static CodecTypeMap map {
-        {
-            ast::tokens::FLOAT,
-            {
+    // If on X86, see if the hardware supports f16c. For other platforms we
+    // currently assume hardware support for half/float conversion. This only
+    // applies to the truncate codec.
+    // @todo  Add software support. Will be simpler with AX function support.
+    static bool HasF16C =
+        ax::x86::CheckX86Feature("f16c") != ax::x86::CpuFlagStatus::Unsupported;
+
+    static auto GetFloatCodecs = []() -> CodecNameMap {
+        if (HasF16C) {
+            return {
                 { points::TruncateCodec::name(),                             codecs[0].get() },
                 { points::FixedPointCodec<true, points::UnitRange>::name(),  codecs[1].get() },
                 { points::FixedPointCodec<false, points::UnitRange>::name(), codecs[2].get() }
-            }
-        },
-        {
-            ast::tokens::VEC3F,
-            {
+            };
+        }
+        else {
+            return {
+                { points::FixedPointCodec<true, points::UnitRange>::name(),  codecs[1].get() },
+                { points::FixedPointCodec<false, points::UnitRange>::name(), codecs[2].get() }
+            };
+        }
+    };
+
+    static auto GetVectorCodecs = []() -> CodecNameMap {
+        if (HasF16C) {
+            return {
                 { points::TruncateCodec::name(),                                 codecs[0].get() },
                 { points::FixedPointCodec<true, points::UnitRange>::name(),      codecs[1].get() },
                 { points::FixedPointCodec<false, points::UnitRange>::name(),     codecs[2].get() },
                 { points::FixedPointCodec<true, points::PositionRange>::name(),  codecs[3].get() },
                 { points::FixedPointCodec<false, points::PositionRange>::name(), codecs[4].get() }
-            }
+            };
+        }
+        else {
+            return {
+                { points::FixedPointCodec<true, points::UnitRange>::name(),      codecs[1].get() },
+                { points::FixedPointCodec<false, points::UnitRange>::name(),     codecs[2].get() },
+                { points::FixedPointCodec<true, points::PositionRange>::name(),  codecs[3].get() },
+                { points::FixedPointCodec<false, points::PositionRange>::name(), codecs[4].get() }
+            };
+        }
+    };
+
+    static CodecTypeMap map {
+        {
+            ast::tokens::FLOAT, GetFloatCodecs()
+        },
+        {
+            ast::tokens::VEC3F, GetVectorCodecs()
         },
     };
 
