@@ -74,9 +74,10 @@ public:
     /// @{
     /// Required interface methods
     bool                isDegenerate() const override;
-    int                 getBBox(UT_BoundingBox *bbox) const override;
+    bool                getBBox(UT_BoundingBox *bbox) const override;
     void                reverse() override;
     UT_Vector3          computeNormal() const override;
+    UT_Vector3D         computeNormalD() const override;
     void                copyPrimitive(const GEO_Primitive *src) override;
     void                copySubclassData(const GA_Primitive *source) override;
 
@@ -196,6 +197,14 @@ public:
     // ignored.
     void                transform(const UT_Matrix4 &mat) override;
 
+
+    /// True if the underlying grid has no voxels.
+    bool                 isEmpty() const { return getGridPtr()->empty(); }
+
+    /// Background value of the grid as a scalar or vector.
+    fpreal               backgroundF() const;
+    UT_Vector3D          backgroundV3() const;
+
     /// Accessors for the 4x4 matrix representing the affine transform that
     /// converts from index space voxel coordinates to world space. For frustum
     /// maps, this will be transform as if the taper value is set to 1.
@@ -282,6 +291,7 @@ public:
     /// Returns the resolution of the active voxel array.
     /// Does *not* mean the indices go from 0..rx, however!
     void                getRes(int &rx, int &ry, int &rz) const;
+    void                getRes(int64 &rx, int64 &ry, int64 &rz) const;
 
     /// Computes the voxel diameter by taking a step in x, y, and z
     /// converting to world space and taking the length of that vector.
